
.. _conformance:

Standards conformance
*********************
This page links to pages documenting standard conformance for different
standards or file :doc:`formats <index>`.

.. _conformance#lisa_and_oasis_standards:

LISA and OASIS standards
========================

* :doc:`tmx`
* :doc:`xliff`
* :doc:`tbx`

.. _conformance#other_formats:

Other formats
=============

* :doc:`Gettext PO <po>`
* :doc:`Gettext .mo <mo>`
* :doc:`csv`
* :doc:`Qt Linguist <ts>`
* Qt .qph and .qm files
* :doc:`Wordfast translation memory <wordfast>`
* OmegaT glossary

.. _conformance#searching_and_matching:

Searching and matching
======================

* :doc:`Levenshtein distance </commands/levenshtein_distance>`
